**DO DESMATAMENTO EM ÁREA DE VEGETAÇÃO SECUNDÁRIA**

[START_INDENTATION] A limpeza de pastagem no Estado de Mato Grosso, depois da revogação do inciso VIII do artigo 1º do Decreto nº 2.151 de 12/02/2014) em 2016 (pelo Decreto nº 420, publicado no dia 5 de fevereiro de 2016) passou a ser disciplinada pelo art. 2o da Instrução Normativa 12 de 2016 da SEMA, de seguinte teor:

[INDENTBY 4cm] "Art. 2º Para fins desta Instrução Normativa, entende-se como limpeza de áreas em imóveis rurais as operações que envolvam roçada, retirada de plantas oportunistas e invasoras em regeneração natural que tenha até 50 (cinquenta) indivíduos por hectare com Diâmetro Altura do Peito-DAP com até 10 (dez) centímetros, sem derrubada de árvores adultas, desde que sejam realizadas: 
I - em áreas consolidadas ou em áreas abertas após 22 de julho de 2008, autorizada ou regularizada pelos órgãos ambientais competentes, e 
II- em áreas cujo tempo de pousio seja de até 5 (cinco) anos ou que não ultrapasse a 3 (três) anos, quando se tratar de áreas abandonadas."

No caso concreto, a materialidade de desmatamento ilegal na área foi concluída por diversos órgãos diferentes, não havendo dúvida que não se trata de mera limpeza de pastagem.

De fato, os elementos informativos que comprovam o desmatamento ilegal são vários:
* A resolução dos Alertas da Plataforma Global Forest Watch, utilizada pela Promotoria de Justiça de Itiquira (no âmbito do Projeto Olhos da Mata, vencedor da XVI Edição do Prêmio Innovare - categoria Ministério Público) destina-se a identificação de desflorestamento de formação vegetal em densidade superior à mera limpeza irregular de pastagem;
* Relatório Técnico do CAO do Ministério Público do Estado de Mato Grosso;
* Autos de infração N. _ lavrados pelo órgão de fiscalização administrativa;

Os alertas GLAD são gerados a partir de imagens do satélite Landsat 8, cujo algoritmo de processamento desenvolvido identifica alterações em áreas cobertas por árvores acima de 5m de altura e com densidade de cobertura do solo acima de 60%. A validação dos alertas, feitas no Peru, identificou a ocorrência de aproximadamente 13% de falsos-positivos (emissão de alertas em áreas em que não houve perda de cobertura arbórea) e 33% de falsos-negativos (não emissão de alertas em áreas em que houve perda de cobertura arbórea), portanto, pode-se considerar o método como conservador se avaliado pela sua acurácia. O detalhamento da metodologia e dos resultados alcançados podem ser consultados em Hansen et al. (2016).

Os mencionados alertas GLAD possuem a seguinte especificação técnica:

- Alerta: GLAD
 
 - Função: Identificação de perdas de cobertura arbórea

 - Resolução espacial: 30m x 30m

 - Cobertura geográfica: Entre 30°N e 30°S

 - Limitações: Nuvens; não distinção entre florestas naturais ou artificiais e perdas por causa antrópica ou natural

 - Atualização: Semanal

 - Data do conteúdo: A partir de janeiro de 2018 (de 2015 em alguns países)

(Fonte: Global Land Analysis and Discovery Lab, University of Maryland, EUA - https://www.globalforestwatch.org/)

Logo, a atividade praticada não se subsume à mera limpeza de pastagens que, no Estado de Mato Grosso, desde 2016 encontra definição normativa no art. 2º da Instrução Normativa n. 012, de 12 de fevereiro de 2016, acima transcrita.

O volume das árvores em questão (nativas do Cerrado e, portanto, de crescimento relativamente lento), bem como a densidade florestal observada (superior a 60% de área com árvores com altura superior a 05 metros) é incompatível com a limpeza de pastagem, que se limita à “roçada” (limpeza com a roçadeira ou instrumentos singelos) de pequenas árvores e arbustos.

Os critérios envolvendo a diferenciação de limpeza de pastagens e desmatamento são objetivos e esse entendimento encontra-se exaustivamente explicada pela Secretaria de Estado de Meio Ambiente - SEMA, conforme se depreende da notícia abaixo:

[INDENTBY 4cm] *A partir desta semana, o produtor rural de Mato Grosso que realizar limpeza de áreas em imóveis rurais deverá protocolar a ‘declaração de limpeza’ antes do início da atividade no endereço eletrônico da Secretaria de Estado de Meio Ambiente (Sema). (...)
Conforme a secretária Ana Luiza Peterlini (...) “Cobrar essa declaração demonstra que o Governo está levando a sério o compromisso firmado na COP 21 de Paris de zerar o desmatamento ilegal até 2020”
Ana Luiza pontua que a Sema não está exigindo que o produtor peça ‘autorização’ do órgão ambiental para o procedimento, mas apenas tornou obrigatório que declare antecipadamente quando for fazer a limpeza, conforme já regulamentava o Decreto nº 2.151/2014, que foi mantido pelo Decreto nº 420, publicado no dia 5 de fevereiro deste ano. A única novidade é ter revogado o inciso VIII do antigo decreto que não cobrava a comunicação de limpeza à Sema. (...) 
É importante esclarecer que a Instrução Normativa nº 12, publicada no dia 15 de fevereiro, cobra a comunicação apenas daqueles produtores que forem fazer a limpeza de áreas que envolvam roçada, retirada de plantas oportunistas e invasoras em regeneração - que tenha até 50 centímetros por hectare com diâmetro altura do peito (DAP) com até 10 centímetros -, sem derrubada de árvores adultas. Sobre o pousio, a legislação informa que são consideradas apenas aquelas áreas em repouso por um período de até 5 anos, mas desde que não estejam abandonadas. Caso contrário, já não se trata mais de ‘limpeza de área’ e sim de desmatamento e precisa de autorização do órgão ambiental para a realização. “Se o produtor abriu a área na década de 1990, utilizou por um período e depois abandonou por mais de 5 anos e a área já se regenerou não se encaixa em limpeza, é desmatamento”, reforça a secretária adjunta de Gestão Ambiental, Elaine Corsini.* (fonte: http://www.mt.gov.br/-/2998633-sema-orienta-produtor-sobre-limpeza-de-areas-rurais - g.n.)

Quanto à alegação de a área ser consolidada, esta não prospera, já que florestas desmatadas que se regeneram possuem proteção legal. 

O marco temporal de 22/07/2008 serviu para anistiar crimes e infrações administrativas ocorridas antes desta data – e não como um direito perpétuo de destruir a flora. A propósito, importante ressaltar que, segundo a jurisprudência do Superior Tribunal de Justiça: 

[INDENTBY 4cm] *“(...) inexiste direito adquirido a poluir ou degradar o meio ambiente. O tempo é incapaz de curar ilegalidades ambientais de natureza permanente, pois parte dos sujeitos tutelados - as gerações futuras - carece de voz e de representantes que falem ou se omitam em seu nome.”* (AgInt no REsp 1283547/SC, Rel. Ministra REGINA HELENA COSTA, PRIMEIRA TURMA, julgado em 23/10/2018, DJe 31/10/2018). 

Note-se que não só a vegetação primária ou prístina, mas também a secundária (não só em estágio avançado como médio de regeneração) recebe proteção do ordenamento jurídico Brasileiro, até mesmo na esfera penal: 

[BORDER] [INDENTBY 4cm] *Art. 38-A.  Destruir ou danificar vegetação primária ou secundária, em estágio avançado ou médio de regeneração, do Bioma Mata Atlântica, ou utilizá-la com infringência das normas de proteção: 
Pena - detenção, de 1 (um) a 3 (três) anos, ou multa, ou ambas as penas cumulativamente.*  
[BORDER] *Art. 48. Impedir ou dificultar a regeneração natural de florestas e demais formas de vegetação: 
Pena - detenção, de seis meses a um ano, e multa.*


Além disso, uma das florestas mais conhecidas do Brasil, a Floresta da Tijuca, no Rio de Janeiro, é, em grande parte, vegetação secundária, cuja recuperação iniciou-se no século XIX, em razão de deslizamentos e, principalmente, a crise hídrica no Rio de Janeiro levaram o imperador Pedro II a desapropriar chácaras dos nobres que haviam se instalado nas encostas da floresta e determinado o reflorestamento, o maior promovido até então no país.

![](https://upload.wikimedia.org/wikipedia/commons/thumb/d/d2/Rugendas_-_Defrichement_d_une_Foret.jpg/313px-Rugendas_-_Defrichement_d_une_Foret.jpg)

*Pintura de Rugendas, do século XIX, retratando a derrubada da Floresta da Tijuca, hoje umas mais importantes florestas do Rio de Janeiro*

Portanto, se a intervenção não autorizada elimita as espécies arbóreas adultas, não há que se falar em limpeza de pastagem, mas em destamento ilegal em área de vegetação secundária, que também recebe de nosso ordenamento jurídico proteção jurídica, mormente após o período de cinco anos (período de pousio).